]> git.cworth.org Git - wordgame/blobdiff - grid.h
Increase the window size a bit
[wordgame] / grid.h
diff --git a/grid.h b/grid.h
index 3d200c7e81d8efbd77c133bb826010ab44aa747c..b73e9b2a8aabc618e14d8d2ecfa36421f527e18f 100644 (file)
--- a/grid.h
+++ b/grid.h
@@ -1,7 +1,7 @@
 /*
  * Copyright © 2006 Carl Worth
  *
- * This program is free software; you can redistribute it and\/or modify
+ * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
 
 #include "dict.h"
 
+#define GRID_SIZE_MAX 5
 /* (  3 chars per cell
- *  x 4 cells per row
+ *  x GRID_SIZE_MAX cells per row
  *  + 1 newline per row
* ) x 4 rows per grid
  *   + 1 terminator character
- * = 53
  */
-#define GRID_STRING_MAX 53
+#define GRID_STRING_MAX (((3 * GRID_SIZE_MAX + 1) * GRID_SIZE_MAX) + 1)
 
 typedef struct _grid {
-    char letters[4][4];
+    int size;
+    char letters[GRID_SIZE_MAX][GRID_SIZE_MAX];
     char string[GRID_STRING_MAX];
 
     /* Private, transient state used by enumerate */
     dict_t *results;
 } grid_t;
 
+/* size must be 4 or 5 */
 void
-grid_init (grid_t *grid);
+grid_init (grid_t *grid, int size);
+
+void
+grid_set_letters (grid_t       *grid,
+                 const char    *letters);
 
 char *
 grid_string (grid_t *grid);
@@ -1,7 +1,7 @@
  *  + 1 newline per row
- * ) x 4 rows per grid
+ * ) x GRID_SIZE_MAX rows per grid
  *   + 1 terminator character